import time

from miose_toolkit_logger import logger

from .config import config

logger.set_log_level(config.APP_LOG_LEVEL)
logger.set_log_format(
    "<g>{time:MM-DD HH:mm:ss}</g> "
    "[<lvl>{level}</lvl>] "
    "<c><u>{name}</u></c> | "
    "<c>{function}:{line}</c>| "
    "{message}",
)

logger.set_log_output(f"logs/{time.strftime('%Y-%m-%d-%H-%M-%S')}.log", with_console=True)
logger.success("Logger initialized")
print("logger initialized")



from miose_toolkit_db import MioOrm, gen_postgresql_db_url, gen_sqlite_db_url

from nekro_agent.core.args import Args

from .config import config

if not Args.LOAD_TEST:
    orm: MioOrm = MioOrm(
        gen_postgresql_db_url(
            host=config.POSTGRES_HOST,
            port=config.POSTGRES_PORT,
            user=config.POSTGRES_USER,
            password=config.POSTGRES_PASSWORD,
            database=config.POSTGRES_DATABASE,
        ),
    )

else:
    orm: MioOrm = MioOrm(gen_sqlite_db_url(".temp/load_test.db"))
